aboutsummaryrefslogtreecommitdiffstats
path: root/file.go
diff options
context:
space:
mode:
Diffstat (limited to 'file.go')
-rw-r--r--file.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/file.go b/file.go
index 3278a8c..c5a6d42 100644
--- a/file.go
+++ b/file.go
@@ -6,7 +6,7 @@ import (
"os"
"strings"
- "gopkg.in/src-d/go-git.v4/core"
+ "gopkg.in/src-d/go-git.v4/plumbing/storer"
)
// File represents git file objects.
@@ -83,7 +83,7 @@ func (iter *FileIter) Next() (*File, error) {
}
// ForEach call the cb function for each file contained on this iter until
// an error happends or the end of the iter is reached. If core.ErrStop is sent
// the iteration is stop but no error is returned. The iterator is closed.
func (iter *FileIter) ForEach(cb func(*File) error) error {
defer iter.Close()
@@ -99,7 +99,7 @@ func (iter *FileIter) ForEach(cb func(*File) error) error {
}
if err := cb(f); err != nil {
- if err == core.ErrStop {
+ if err == storer.ErrStop {
return nil
}
@@ -83,7 +83,7 @@ func (iter *FileIter) Next() (*File, error) {
}
// ForEach call the cb function for each file contained on this iter until
-// an error happends or the end of the iter is reached. If core.ErrStop is sent
+// an error happends or the end of the iter is reached. If plumbing.ErrStop is sent
// the iteration is stop but no error is returned. The iterator is closed.
func (iter *FileIter) ForEach(cb func(*File) error) error {